@@ -51,6 +51,7 @@ Torus Knot Software Ltd.
 #include "OgreAnimation.h"
 #include "OgreAlignedAllocator.h"
 #include "OgreOptimisedUtil.h"
+#include "OgreSceneNode.h"
 
 namespace Ogre {
     //-----------------------------------------------------------------------
@@ -68,6 +69,7 @@ namespace Ogre {
 		  mSharedSkeletonEntities(NULL),
 		  mDisplaySkeleton(false),
 	      mHardwareAnimation(false),
+		  mHardwarePoseCount(0),
 		  mVertexProgramInUse(false),
 		  mSoftwareAnimationRequests(0),
 		  mSoftwareAnimationNormalsRequests(0),
@@ -195,7 +197,13 @@ namespace Ogre {
 		}
 
 		reevaluateVertexProcessing();
-
+		
+		// Update of bounds of the parent SceneNode, if Entity already attached
+		// this can happen if Mesh is loaded in background or after reinitialisation
+		if( mParentNode )
+		{
+			getParentSceneNode()->_updateBounds();
+		}
 
 		mInitialised = true;
 
@@ -279,6 +287,8 @@ namespace Ogre {
     Entity::~Entity()
     {
 		_deinitialise();
+		// Unregister our listener
+		mMesh->removeListener(this);
     }
 	//-----------------------------------------------------------------------
 	bool Entity::hasVertexAnimation(void) const
