@@ -308,7 +308,9 @@ static const size_t depthBits[] =
                     {
                         // Packed depth/stencil format
 
-#if OGRE_PLATFORM == OGRE_PLATFORM_LINUX
+// #if OGRE_PLATFORM == OGRE_PLATFORM_LINUX
+// It now seems as if this workaround now *breaks* nvidia cards on Linux with the 169.12 drivers on Linux
+#if 0
                         // Only query packed depth/stencil formats for 32-bit
                         // non-floating point formats (ie not R32!) 
                         // Linux nVidia driver segfaults if you query others
@@ -337,6 +339,11 @@ static const size_t depthBits[] =
             // Delete texture and framebuffer
             glBindFramebufferEXT(GL_FRAMEBUFFER_EXT, 0);
             glDeleteFramebuffersEXT(1, &fb);
+			
+			// Workaround for NVIDIA / Linux 169.21 driver problem
+			// see http://www.ogre3d.org/phpBB2/viewtopic.php?t=38037&start=25
+			glFinish();
+			
             if (fmt!=GL_NONE)
                 glDeleteTextures(1, &tid);
         }
