@@ -195,8 +195,6 @@ namespace Ogre {
 		RenderWindow* autoWindow = mGLSupport->createWindow(autoCreateWindow, this, windowTitle);
 
 
-        _setCullingMode( mCullingMode );
-        
         return autoWindow;
     }
 
@@ -224,7 +222,14 @@ namespace Ogre {
         // Check for hardware mipmapping support.
         if(GLEW_VERSION_1_4 || GLEW_SGIS_generate_mipmap)
         {
-            mCapabilities->setCapability(RSC_AUTOMIPMAP);
+			bool disableAutoMip = false;
+#if OGRE_PLATFORM == OGRE_PLATFORM_APPLE
+			// Apple ATI drivers have faults in hardware mipmap generation
+			if (mGLSupport->getGLVendor().find("ATI") != std::string::npos)
+				disableAutoMip = true;
+#endif
+			if (!disableAutoMip)				
+				mCapabilities->setCapability(RSC_AUTOMIPMAP);
         }
 
         // Check for blending support
@@ -456,12 +461,16 @@ namespace Ogre {
 		// Check for texture compression
         if(GLEW_VERSION_1_3 || GLEW_ARB_texture_compression)
         {   
-            mCapabilities->setCapability(RSC_TEXTURE_COMPRESSION);
+			mCapabilities->setCapability(RSC_TEXTURE_COMPRESSION);
          
             // Check for dxt compression
             if(GLEW_EXT_texture_compression_s3tc)
             {
-                mCapabilities->setCapability(RSC_TEXTURE_COMPRESSION_DXT);
+#if defined(__APPLE__) && defined(__PPC__)
+			// Apple on ATI & PPC has errors in DXT
+			if (mGLSupport->getGLVendor().find("ATI") == std::string::npos)
+#endif
+					mCapabilities->setCapability(RSC_TEXTURE_COMPRESSION_DXT);
             }
             // Check for vtc compression
             if(GLEW_NV_texture_compression_vtc)
@@ -561,7 +570,7 @@ namespace Ogre {
 			{
 				GLint buffers;
 				glGetIntegerv(GL_MAX_DRAW_BUFFERS_ARB, &buffers);
-				mCapabilities->setNumMultiRenderTargets(std::min(buffers, OGRE_MAX_MULTIPLE_RENDER_TARGETS));
+				mCapabilities->setNumMultiRenderTargets(std::min<int>(buffers, OGRE_MAX_MULTIPLE_RENDER_TARGETS));
 				if(!GLEW_VERSION_2_0)
 				{
 					// Before GL version 2.0, we need to get one of the extensions
@@ -1568,7 +1577,7 @@ namespace Ogre {
     String GLRenderSystem::getErrorDescription(long errCode) const
     {
         const GLubyte *errString = gluErrorString (errCode);
-        return String((const char*) errString);
+		return (errString != 0) ? String((const char*) errString) : StringUtil::BLANK;
     }
     //-----------------------------------------------------------------------------
     void GLRenderSystem::setLightingEnabled(bool enabled)
@@ -1646,6 +1655,11 @@ namespace Ogre {
         }
         else
         {
+		// unbind GPU programs at end of frame
+		// this is mostly to avoid holding bound programs that might get deleted
+		// outside via the resource manager
+		unbindGpuProgram(GPT_VERTEX_PROGRAM);
+		unbindGpuProgram(GPT_FRAGMENT_PROGRAM);
             q = -(farPlane + nearPlane) / (farPlane - nearPlane);
             qn = -2 * (farPlane * nearPlane) / (farPlane - nearPlane);
         }
@@ -2225,6 +2239,7 @@ namespace Ogre {
             op.vertexData->vertexDeclaration->getElements();
         VertexDeclaration::VertexElementList::const_iterator elem, elemEnd;
         elemEnd = decl.end();
+		std::vector<GLuint> attribsBound;
 
         for (elem = decl.begin(); elem != elemEnd; ++elem)
         {
@@ -2250,95 +2265,103 @@ namespace Ogre {
 
             unsigned int i = 0;
 			VertexElementSemantic sem = elem->getSemantic();
-            switch(sem)
-            {
-            case VES_POSITION:
-                glVertexPointer(VertexElement::getTypeCount(
-                    elem->getType()), 
-                    GLHardwareBufferManager::getGLType(elem->getType()), 
-                    static_cast<GLsizei>(vertexBuffer->getVertexSize()), 
-                    pBufferData);
-                glEnableClientState( GL_VERTEX_ARRAY );
-                break;
-            case VES_NORMAL:
-                glNormalPointer(
-                    GLHardwareBufferManager::getGLType(elem->getType()), 
-                    static_cast<GLsizei>(vertexBuffer->getVertexSize()), 
-                    pBufferData);
-                glEnableClientState( GL_NORMAL_ARRAY );
-                break;
-            case VES_DIFFUSE:
-                glColorPointer(4, 
-                    GLHardwareBufferManager::getGLType(elem->getType()), 
-                    static_cast<GLsizei>(vertexBuffer->getVertexSize()), 
-                    pBufferData);
-                glEnableClientState( GL_COLOR_ARRAY );
-                break;
-            case VES_SPECULAR:
-				if (GLEW_EXT_secondary_color)
-				{
-					glSecondaryColorPointerEXT(4, 
-						GLHardwareBufferManager::getGLType(elem->getType()), 
-						static_cast<GLsizei>(vertexBuffer->getVertexSize()), 
-						pBufferData);
-					glEnableClientState( GL_SECONDARY_COLOR_ARRAY );
-				}
-                break;
-            case VES_TEXTURE_COORDINATES:
-
-				if (mCurrentVertexProgram)
-				{
-					// Programmable pipeline - direct UV assignment
-					glClientActiveTextureARB(GL_TEXTURE0 + elem->getIndex());
-					glTexCoordPointer(
-						VertexElement::getTypeCount(elem->getType()), 
-						GLHardwareBufferManager::getGLType(elem->getType()),
-						static_cast<GLsizei>(vertexBuffer->getVertexSize()), 
-						pBufferData);
-					glEnableClientState( GL_TEXTURE_COORD_ARRAY );
-				}
-				else
-				{
-					// fixed function matching to units based on tex_coord_set
-					for (i = 0; i < mDisabledTexUnitsFrom; i++)
-					{
-						// Only set this texture unit's texcoord pointer if it
-						// is supposed to be using this element's index
-						if (mTextureCoordIndex[i] == elem->getIndex())
-						{
-							glClientActiveTextureARB(GL_TEXTURE0 + i);
-							glTexCoordPointer(
-								VertexElement::getTypeCount(elem->getType()), 
-								GLHardwareBufferManager::getGLType(elem->getType()),
-								static_cast<GLsizei>(vertexBuffer->getVertexSize()), 
-									pBufferData);
-							glEnableClientState( GL_TEXTURE_COORD_ARRAY );
-						}
-					}
-				}
-                break;
-            case VES_BLEND_INDICES:
-            case VES_BLEND_WEIGHTS:
-			case VES_TANGENT:
-			case VES_BINORMAL:
-				if (mCurrentVertexProgram)
-				{
-					GLuint attrib = mCurrentVertexProgram->getAttributeIndex(sem);
-	                glVertexAttribPointerARB(
-    	                attrib,
-        	            VertexElement::getTypeCount(elem->getType()), 
-            	        GLHardwareBufferManager::getGLType(elem->getType()), 
-                	    GL_FALSE, // normalisation disabled
-                    	static_cast<GLsizei>(vertexBuffer->getVertexSize()), 
-	                    pBufferData);
-    	            glEnableVertexAttribArrayARB(attrib);
-					
-				}
-                break;
-            default:
-                break;
-            };
-
+ 
+ 			bool isCustomAttrib = false;
+ 			if (mCurrentVertexProgram)
+ 				isCustomAttrib = mCurrentVertexProgram->isAttributeValid(sem, elem->getIndex());
+ 
+ 			// Custom attribute support
+ 			// tangents, binormals, blendweights etc always via this route
+ 			// builtins may be done this way too
+ 			if (isCustomAttrib)
+ 			{
+ 				GLint attrib = mCurrentVertexProgram->getAttributeIndex(sem, elem->getIndex());
+ 				glVertexAttribPointerARB(
+ 					attrib,
+ 					VertexElement::getTypeCount(elem->getType()), 
+  					GLHardwareBufferManager::getGLType(elem->getType()), 
+ 					GL_FALSE, // normalisation disabled
+  					static_cast<GLsizei>(vertexBuffer->getVertexSize()), 
+  					pBufferData);
+ 				glEnableVertexAttribArrayARB(attrib);
+ 
+ 				attribsBound.push_back(attrib);
+ 			}
+ 			else
+ 			{
+ 				// fixed-function & builtin attribute support
+ 				switch(sem)
+  				{
+ 				case VES_POSITION:
+ 					glVertexPointer(VertexElement::getTypeCount(
+ 						elem->getType()), 
+  						GLHardwareBufferManager::getGLType(elem->getType()), 
+  						static_cast<GLsizei>(vertexBuffer->getVertexSize()), 
+  						pBufferData);
+ 					glEnableClientState( GL_VERTEX_ARRAY );
+ 					break;
+ 				case VES_NORMAL:
+ 					glNormalPointer(
+ 						GLHardwareBufferManager::getGLType(elem->getType()), 
+  						static_cast<GLsizei>(vertexBuffer->getVertexSize()), 
+  						pBufferData);
+ 					glEnableClientState( GL_NORMAL_ARRAY );
+ 					break;
+ 				case VES_DIFFUSE:
+ 					glColorPointer(4, 
+  						GLHardwareBufferManager::getGLType(elem->getType()), 
+  						static_cast<GLsizei>(vertexBuffer->getVertexSize()), 
+  						pBufferData);
+ 					glEnableClientState( GL_COLOR_ARRAY );
+ 					break;
+ 				case VES_SPECULAR:
+ 					if (GLEW_EXT_secondary_color)
+ 					{
+ 						glSecondaryColorPointerEXT(4, 
+ 							GLHardwareBufferManager::getGLType(elem->getType()), 
+ 							static_cast<GLsizei>(vertexBuffer->getVertexSize()), 
+ 							pBufferData);
+ 						glEnableClientState( GL_SECONDARY_COLOR_ARRAY );
+ 					}
+ 					break;
+ 				case VES_TEXTURE_COORDINATES:
+  
+ 					if (mCurrentVertexProgram)
+ 					{
+ 						// Programmable pipeline - direct UV assignment
+ 						glClientActiveTextureARB(GL_TEXTURE0 + elem->getIndex());
+ 						glTexCoordPointer(
+ 							VertexElement::getTypeCount(elem->getType()), 
+ 							GLHardwareBufferManager::getGLType(elem->getType()),
+ 							static_cast<GLsizei>(vertexBuffer->getVertexSize()), 
+ 							pBufferData);
+ 						glEnableClientState( GL_TEXTURE_COORD_ARRAY );
+ 					}
+ 					else
+ 					{
+ 						// fixed function matching to units based on tex_coord_set
+ 						for (i = 0; i < mDisabledTexUnitsFrom; i++)
+ 						{
+ 							// Only set this texture unit's texcoord pointer if it
+ 							// is supposed to be using this element's index
+ 							if (mTextureCoordIndex[i] == elem->getIndex())
+ 							{
+ 								glClientActiveTextureARB(GL_TEXTURE0 + i);
+ 								glTexCoordPointer(
+ 									VertexElement::getTypeCount(elem->getType()), 
+ 									GLHardwareBufferManager::getGLType(elem->getType()),
+ 									static_cast<GLsizei>(vertexBuffer->getVertexSize()), 
+ 									pBufferData);
+ 								glEnableClientState( GL_TEXTURE_COORD_ARRAY );
+ 							}
+ 						}
+ 					}
+ 					break;
+ 				default:
+ 					break;
+ 				};
+ 			} // isCustomAttrib
+  
         }
 
         glClientActiveTextureARB(GL_TEXTURE0);
@@ -2415,35 +2438,14 @@ namespace Ogre {
 		{
 			glDisableClientState( GL_SECONDARY_COLOR_ARRAY );
 		}
-        if (mCurrentVertexProgram)
-        {
-			// unbind any custom attributes
-			if (mCurrentVertexProgram->isAttributeValid(VES_BLEND_INDICES))
-			{
-				glDisableVertexAttribArrayARB(
-					mCurrentVertexProgram->getAttributeIndex(
-						VES_BLEND_INDICES)); 
-			}
-			if (mCurrentVertexProgram->isAttributeValid(VES_BLEND_WEIGHTS))
-			{
-				glDisableVertexAttribArrayARB(
-					mCurrentVertexProgram->getAttributeIndex(
-						VES_BLEND_WEIGHTS)); 
-			}
-			if (mCurrentVertexProgram->isAttributeValid(VES_TANGENT))
-			{
-				glDisableVertexAttribArrayARB(
-					mCurrentVertexProgram->getAttributeIndex(
-						VES_TANGENT)); 
-			}
-			if (mCurrentVertexProgram->isAttributeValid(VES_BINORMAL))
-			{
-				glDisableVertexAttribArrayARB(
-					mCurrentVertexProgram->getAttributeIndex(
-						VES_BINORMAL)); 
-			}
-        }
-        glColor4f(1,1,1,1);
+ 		// unbind any custom attributes
+		for (std::vector<GLuint>::iterator ai = attribsBound.begin(); ai != attribsBound.end(); ++ai)
+ 		{
+ 			glDisableVertexAttribArrayARB(*ai); 
+ 
+  		}
+		
+		glColor4f(1,1,1,1);
 		if (GLEW_EXT_secondary_color)
 		{
 			glSecondaryColor3fEXT(0.0f, 0.0f, 0.0f);
@@ -2559,7 +2561,15 @@ namespace Ogre {
         size_t numClipPlanes;
         GLdouble clipPlane[4];
 
-        numClipPlanes = clipPlanes.size();
+		// Save previous modelview
+		glMatrixMode(GL_MODELVIEW);
+		glPushMatrix();
+		// just load view matrix (identity world)
+		GLfloat mat[16];
+		makeGLMatrix(mat, mViewMatrix);
+		glLoadMatrixf(mat);
+
+		numClipPlanes = clipPlanes.size();
         for (i = 0; i < numClipPlanes; ++i)
         {
             GLenum clipPlaneId = static_cast<GLenum>(GL_CLIP_PLANE0 + i);
@@ -2585,6 +2595,10 @@ namespace Ogre {
         {
             glDisable(static_cast<GLenum>(GL_CLIP_PLANE0 + i));
         }
+
+		// restore matrices
+		glPopMatrix();
+		
     }
 	//---------------------------------------------------------------------
     void GLRenderSystem::setScissorTest(bool enabled, size_t left, 
