@@ -130,6 +130,18 @@ namespace Ogre {
 		// If we can do automip generation and the user desires this, do so
 		mMipmapsHardwareGenerated = 
 			Root::getSingleton().getRenderSystem()->getCapabilities()->hasCapability(RSC_AUTOMIPMAP);
+		// NVIDIA 175.16 drivers break hardware mip generation for non-compressed
+		// textures - disable until fixed
+		// Leave hardware gen on compressed textures since that's the only way we
+		// can realistically do it since GLU doesn't support DXT
+		// However DON'T do this on Apple, their drivers aren't subject to this
+		// problem yet and in fact software generation appears to cause a crash 
+		// in some cases which I've yet to track down
+#if OGRE_PLATFORM != OGRE_PLATFORM_APPLE
+		if (mGLSupport.getGLVendor().find("NVIDIA") != std::string::npos
+			&& !PixelUtil::isCompressed(mFormat))
+			mMipmapsHardwareGenerated = false;
+#endif
 		if((mUsage & TU_AUTOMIPMAP) &&
 		    mNumRequestedMipmaps && mMipmapsHardwareGenerated)
         {
@@ -142,10 +154,7 @@ namespace Ogre {
 		size_t width = mWidth;
 		size_t height = mHeight;
 		size_t depth = mDepth;
-#if 0
-        /** Luckily, this hack seems not to be needed; empty compressed textures can very well be created the 
-            conventional way with glTexImageXD.
-        */
+
 		if(PixelUtil::isCompressed(mFormat))
 		{
 			// Compressed formats
@@ -191,7 +200,6 @@ namespace Ogre {
 			delete [] tmpdata;
 		}
 		else
-#endif
 		{
 			// Run through this process to pregenerate mipmap piramid
 			for(size_t mip=0; mip<=mNumMipmaps; mip++)
