@@ -71,7 +71,11 @@ namespace Ogre {
 #ifdef OGRE_STATIC_LIB
 		HINSTANCE hInst = GetModuleHandle( NULL );
 #else
+#  if OGRE_DEBUG_MODE == 1
+		HINSTANCE hInst = GetModuleHandle("RenderSystem_GL_d.dll");
+#  else
 		HINSTANCE hInst = GetModuleHandle("RenderSystem_GL.dll");
+#  endif
 #endif
 
 		mHWnd = 0;
